[gnome-control-center] ce-page-details: add SAE support



commit 97f6c8f53c15c7ccb9dd7a65ce1ac02ebc18a724
Author: David Bauer <mail david-bauer net>
Date:   Sat Dec 21 17:39:02 2019 +0100

    ce-page-details: add SAE support

 panels/network/connection-editor/ce-page-details.c | 13 +++++++++++--
 1 file changed, 11 insertions(+), 2 deletions(-)
---
diff --git a/panels/network/connection-editor/ce-page-details.c 
b/panels/network/connection-editor/ce-page-details.c
index 3c7fbd51b..dbed2a307 100644
--- a/panels/network/connection-editor/ce-page-details.c
+++ b/panels/network/connection-editor/ce-page-details.c
@@ -97,8 +97,17 @@ get_ap_security_string (NMAccessPoint *ap)
                 g_string_append_printf (str, "%s, ", _("WPA"));
         }
         if (rsn_flags != NM_802_11_AP_SEC_NONE) {
-                /* TRANSLATORS: this WPA WiFi security */
-                g_string_append_printf (str, "%s, ", _("WPA2"));
+#if NM_CHECK_VERSION(1,20,6)
+                if (rsn_flags & NM_802_11_AP_SEC_KEY_MGMT_SAE) {
+                        /* TRANSLATORS: this WPA3 WiFi security */
+                        g_string_append_printf (str, "%s, ", _("WPA3"));
+                }
+               else
+#endif
+               {
+                        /* TRANSLATORS: this WPA WiFi security */
+                        g_string_append_printf (str, "%s, ", _("WPA2"));
+                }
         }
         if ((wpa_flags & NM_802_11_AP_SEC_KEY_MGMT_802_1X) ||
             (rsn_flags & NM_802_11_AP_SEC_KEY_MGMT_802_1X)) {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]